===========
 Changelog
===========

2.12 (2020-03-24)
=================

- Move repository to https://github.com/icemac/icemac.ab.importer.

- Adapt code to `icemac.addressbook >= 9.3`.


2.11 (2019-12-30)
=================

- Adapt code to `icemac.addressbook >= 9.2`.


2.10 (2019-09-28)
=================

- Adapt to new feature in `icemac.addressbook 9.0`: customization of the labels
  of pre-defined fields:

    + use customized labels in import forms

    + do not use field label customizations which are set for file fields on
      fields of import files.

- Adapt tests to `icemac.addressbook >= 9.0`.


Previous versions
=================

See ``OLD_CHANGES.rst`` inside the package.
